<?php
/*
 * Fusio
 * A web-application to create dynamically RESTful APIs
 *
 * Copyright (C) 2015-2016 Christoph Kappestein <christoph.kappestein@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Fusio\Impl\Service;

use Fusio\Impl\Table;
use Fusio\Impl\Service\Log\QueryFilter;
use PSX\Http\Exception as StatusCode;
use PSX\Model\Common\ResultSet;
use PSX\Sql\Condition;
use PSX\Sql\Fields;
use PSX\Sql\Sql;

/**
 * Log
 *
 * @author  Christoph Kappestein <christoph.kappestein@gmail.com>
 * @license http://www.gnu.org/licenses/agpl-3.0
 * @link    http://fusio-project.org
 */
class Log
{
    /**
     * @var \Fusio\Impl\Table\Log
     */
    protected $logTable;

    public function __construct(Table\Log $logTable)
    {
        $this->logTable = $logTable;
    }

    public function getAll($startIndex = 0, QueryFilter $filter)
    {
        $condition = $filter->getCondition();

        return new ResultSet(
            $this->logTable->getCount($condition),
            $startIndex,
            16,
            $this->logTable->getAll(
                $startIndex,
                16,
                'id',
                Sql::SORT_DESC,
                $condition,
                Fields::blacklist(['header', 'body'])
            )
        );
    }

    public function get($logId)
    {
        $log = $this->logTable->get($logId);

        if (!empty($log)) {
            // append errors
            $log['errors'] = $this->logTable->getErrors($log['id']);

            return $log;
        } else {
            throw new StatusCode\NotFoundException('Could not find log');
        }
    }
}
